@@ -13,28 +13,20 @@ mod shared;
 mod timespan;
 mod user;
 
-pub use account::{
-    Account, AccountGoogleIntegration, AccountOutlookIntegration, AccountSettings,
-    AccountWebhookSettings, PEMKey,
-};
+pub use account::{Account, AccountIntegration, AccountSettings, AccountWebhookSettings, PEMKey};
 pub use calendar::{Calendar, CalendarSettings, SyncedCalendar};
 pub use date::format_date;
-pub use event::{
-    CalendarEvent, CalendarEventReminder, SyncedCalendarEvent, SyncedCalendarProvider,
-};
+pub use event::{CalendarEvent, CalendarEventReminder, SyncedCalendarEvent};
 pub use event_instance::{
     get_free_busy, CompatibleInstances, EventInstance, EventWithInstances, FreeBusy,
 };
 pub use reminder::{EventRemindersExpansionJob, Reminder};
 pub use schedule::{Schedule, ScheduleRule};
 pub use service::{
-    BusyCalendar, Service, ServiceMultiPersonOptions, ServiceReservation, ServiceResource,
-    ServiceWithUsers, TimePlan,
+    BusyCalendar, Service, ServiceMultiPersonOptions, ServiceResource, ServiceWithUsers, TimePlan,
 };
 pub use shared::entity::{Entity, ID};
 pub use shared::metadata::{Meta, Metadata};
 pub use shared::recurrence::{RRuleFrequency, RRuleOptions};
 pub use timespan::TimeSpan;
-pub use user::{
-    User, UserGoogleIntegrationData, UserIntegrationProvider, UserOutlookIntegrationData,
-};
+pub use user::{IntegrationProvider, User, UserIntegration};
